/*
 * Copyright (c) 2022 Nordic Semiconductor
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <zephyr/kernel.h>
#include <zephyr/linker/linker-defs.h>

#include <fw_info.h>
#include <ncs_version.h>
#include "common.h"

#if defined(CONFIG_SOC_NRF9160)
#    include <tfm_ioctl_api.h>
#endif

#include <zephyr/logging/log.h>
LOG_MODULE_REGISTER(main);

static int read_s0_active(uint32_t s0_address, uint32_t s1_address,
                          bool *const s0_active)
{
    if (!s0_active) {
        return -EINVAL;
    }

#if defined(CONFIG_SOC_NRF9160)
    return tfm_platform_s0_active(s0_address, s1_address, s0_active);
#else

#endif
}

static void read_s0_s1_version(void)
{
#if defined(CONFIG_SOC_NRF9160)
    struct fw_info s0, s1;
    int rc = tfm_platform_firmware_info(PM_S0_ADDRESS, &s0);
    if (rc == 0) {
        LOG_INF("s0 version: %d", s0.version);
    }

    rc = tfm_platform_firmware_info(PM_S1_ADDRESS, &s1);
    if (rc == 0) {
        LOG_INF("s1 version: %d", s1.version);
    }
#else

#endif
}

int main(void)
{
    LOG_INF("Address of sample %p", (void *)__rom_region_start);
    LOG_INF("Hello sysbuild with mcuboot! %s", CONFIG_BOARD);
    LOG_INF("NCS version: %s", NCS_VERSION_STRING);

    bool s0_active;
    int rc = read_s0_active(PM_S0_ADDRESS, PM_S1_ADDRESS, &s0_active);
    if (rc == 0) {
        LOG_INF("Active slot: %s", s0_active ? "s0" : "s1");
    }
    read_s0_s1_version();

    for (uint8_t i = 0; i < 5; i++) {
        LOG_INF("Hello from Zephyr! %s", CONFIG_BOARD);
        k_sleep(K_SECONDS(1));
    }

    return 0;
}
